Documentation
¶
Overview ¶
This package has the automatically generated typed clients.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type RouteClient ¶
type RouteClient struct {
// contains filtered or unexported fields
}
RouteClient is used to interact with features provided by the route.openshift.io group.
func New ¶
func New(c rest.Interface) *RouteClient
New creates a new RouteClient for the given RESTClient.
func NewForConfig ¶
func NewForConfig(c *rest.Config) (*RouteClient, error)
NewForConfig creates a new RouteClient for the given config.
func NewForConfigOrDie ¶
func NewForConfigOrDie(c *rest.Config) *RouteClient
NewForConfigOrDie creates a new RouteClient for the given config and panics if there is an error in the config.
func (*RouteClient) RESTClient ¶
func (c *RouteClient) RESTClient() rest.Interface
RESTClient returns a RESTClient that is used to communicate with API server by this client implementation.
func (*RouteClient) Routes ¶
func (c *RouteClient) Routes(namespace string) RouteResourceInterface
type RouteInterface ¶
type RouteInterface interface {
RESTClient() rest.Interface
RoutesGetter
}
type RouteResourceExpansion ¶
type RouteResourceExpansion interface{}
type RouteResourceInterface ¶
type RouteResourceInterface interface {
Create(*route.Route) (*route.Route, error)
Update(*route.Route) (*route.Route, error)
UpdateStatus(*route.Route) (*route.Route, error)
Delete(name string, options *v1.DeleteOptions) error
DeleteCollection(options *v1.DeleteOptions, listOptions v1.ListOptions) error
Get(name string, options v1.GetOptions) (*route.Route, error)
List(opts v1.ListOptions) (*route.RouteList, error)
Watch(opts v1.ListOptions) (watch.Interface, error)
Patch(name string, pt types.PatchType, data []byte, subresources ...string) (result *route.Route, err error)
RouteResourceExpansion
}
RouteResourceInterface has methods to work with RouteResource resources.
type RoutesGetter ¶
type RoutesGetter interface {
Routes(namespace string) RouteResourceInterface
}
RoutesGetter has a method to return a RouteResourceInterface. A group's client should implement this interface.